OiRA
Author: Cornelis G. A. Kolbach

# Voorbereiden

Name of country

## Login

E-mail address Password (I forgot my password)
Keep me logged in.

Don't have an account? Then please register first. Uw registratiegegevens zijn privé. De opgeslagen gegevens zijn niet voor anderen toegankelijk.

## What is OiRA?

OiRA stands for Online Interactive Risk Assessment. It is a web-based tool that allows you to perform a health and safety risk assessment of your workplace or business.

#### Who is the OiRA tool for?

OiRA can be used by anyone wishing to assess health and safety-related risks that might exist in their workplace or working environments.

Show more… / Show less…

However, OiRA is designed to be of most value to smaller businesses who are aware of their legal health and safety obligations but may not be in a position to commission a full risk assessment by an external organisation.

Often, employees or owners of these businesses are responsible for health and safety-related activities alongside their other day-to-day responsibilities. OiRA is designed specifically to help people in this position by bringing together in one place the legal context, likely risks to be assessed and the ability to produce a report tailored to the business's requirements.

Previous experience of conducting a risk assessment is not required as OiRA contains all of the information you will need, including comprehensive support documentation and videos covering details of the assessment process and the tool's operation.

#### What do I have to do?

There are four main stages to complete in the assessment process:

Show more… / Show less…

- Preparation: This gives you an overview of the particular assessment you are about to begin and, in some cases, can allow you to further customise the assessment to the specific nature of your business.
- Identification: OiRA will present a series of potential health and safety hazards or problems that could exist in your organisation. You can then identify those that have been addressed or do not exist, those that need to be addressed and those you would like to 'park' just now and return to later.
- Evaluation: Here you will be able to determine the level of risk attached to each of the items you identified as 'need to be addressed' in the 'Identification' stage.
- Action Plan: In the fourth stage of the assessment you will decide what steps you can take to address the risks you have now identified and what resources this might require.

You can then produce a report containing the level of detail you require and in a format that will make it easy to refer to and share electronically or in print.

#### How long will it take?

It's impossible to say how long an assessment will take as each one contains risks that are typically found in working environment(s) relevant to your business sector.

Show more… / Show less…

However, you can spend whatever time you have available on an assessment and then return to it when convenient to pick up from the same point you left off.

#### Why do I have to register?

The first thing you will be asked to do when you begin your first risk assessment is to create an OiRA account - this is a simple and quick process.

Show more… / Show less…

Once you have done this you can simply log in at any time to continue previous assessments or to start new ones.

You can also have more than one assessment in progress at any one time so if it makes sense for you to complete the initial stages of several assessments at the same time, this is entirely possible within OiRA.

#### Do I need to prepare?

You can find any specific requirements regarding documentation you will be asked to refer to during the assessment on the first page after you start the assessment.

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Lorem | Ipsum Dolor | Sit